@@ -14,7 +14,7 @@ class RELU:
 
 class SIGMOID:
   def predict(self, x): 
-    result = np.exp(-self.relu(x))/(1.0 + np.exp(-np.abs(x)))
+    result = np.exp(-self.relu(-x))/(1.0 + np.exp(-np.abs(x)))
     return result
   
   def relu(self, X):
